@@ -23,6 +23,7 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c(".", "X.weights."))
 #' @param esize A numerical value indicating the size of the whisker or ribbon.
 #' @param ralpha A numerical value indicating the transparency of the ribbon.
 #' @param rfill A character value indicating the filling color of the ribbon.
+#' @param facet_labs An optional character vector of facet labels to be used when plotting an interaction with a factor variable.
 #' @param ... Other ggplot aesthetics arguments for points in the dot-whisker plot or lines in the line-ribbon plots. Not currently used.
 #' 
 #' @details \code{interplot.default} is a S3 method from the \code{interplot}. It works on two classes of objects:
@@ -62,9 +63,8 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c(".", "X.weights."))
 
 
 # S3 method for class 'lm' and 'glm'
-interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE, hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
-    set.seed(324)
-
+interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE, hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", facet_labs = NULL, ...) {
+    
     m.class <- class(m)
     m.sims <- arm::sim(m, sims)
     
@@ -207,7 +207,8 @@ interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95
         }
       
       if(plot == TRUE){
-        coef_df$value <- as.factor(coef_df$value)
+        if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+        coef_df$value <- factor(coef_df$value, labels = facet_labs)
         interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, steps = steps, 
                        point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, 
                        rfill = rfill, 
@@ -272,14 +273,15 @@ interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95
         }
     
         if(plot == TRUE){
-          coef_df$value <- as.factor(coef_df$value)
+          if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+          coef_df$value <- factor(coef_df$value, labels = facet_labs)
                     interplot.plot(m = coef_df, hist = hist, steps = steps, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
                                    # ci_diff = ci_diff,
                                    ...) + facet_grid(. ~ value)
         } else {
-                    names(coef) <- c(var2, "coef", "ub", "lb")
-                    return(coef)
-                }
+          names(coef) <- c(var1, "coef", "ub", "lb")
+          return(coef)
+        }
         
     } else {
         
@@ -432,3 +434,4 @@ interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95
       }
     }
 }
+
