@@ -23,6 +23,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c(".", "X.weights."))
 #' @param esize A numerical value indicating the size of the whisker or ribbon.
 #' @param ralpha A numerical value indicating the transparency of the ribbon.
 #' @param rfill A character value indicating the filling color of the ribbon.
+#' @param facet_labs An optional character vector of facet labels to be used when plotting an interaction with a factor variable.
 #' @param ... Other ggplot aesthetics arguments for points in the dot-whisker plot or lines in the line-ribbon plots. Not currently used.
 #' 
 #' @details \code{interplot.mlmmi} is a S3 method from the \code{interplot}. It works on lists of mixed-effects objects with class \code{lmerMod} and \code{glmerMod} generated by \code{mitools} and \code{lme4}.
@@ -45,8 +46,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c(".", "X.weights."))
 #' @export
 
 # Coding function for mlm, mi objects
-interplot.mlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE,hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000,xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
-    set.seed(324)
+interplot.mlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE,hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000,xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", facet_labs = NULL, ...) {
   
   if(predPro == TRUE) stop("Predicted probability is estimated only for general linear models.")
   
@@ -175,7 +175,8 @@ interplot.mlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95,
                 return(coef)
             }
         }
-        coef_df$value <- as.factor(coef_df$value)
+      if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+      coef_df$value <- factor(coef_df$value, labels = facet_labs)
         interplot.plot(m = coef_df, hist = hist, steps = steps, var2_dt = var2_dt, point = point, 
             ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
             ...) + facet_grid(. ~ value)
@@ -212,7 +213,8 @@ interplot.mlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95,
                 return(coef)
             }
         }
-        coef_df$value <- as.factor(coef_df$value)
+      if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+      coef_df$value <- factor(coef_df$value, labels = facet_labs)
         interplot.plot(m = coef_df, point = point) + facet_grid(. ~ value)
         
         
@@ -268,7 +270,7 @@ interplot.mlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95,
 
 
 #' @export
-interplot.gmlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE, hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
+interplot.gmlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95, adjCI = FALSE, hist = FALSE, var2_dt = NA, predPro = FALSE, var2_vals = NULL, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", facet_labs = NULL, ...) {
   
     set.seed(324)
     
@@ -398,7 +400,8 @@ interplot.gmlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95,
                 return(coef)
             }
         }
-        coef_df$value <- as.factor(coef_df$value)
+      if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+      coef_df$value <- factor(coef_df$value, labels = facet_labs)
         interplot.plot(m = coef_df, steps = steps, hist = hist, var2_dt = var2_dt, point = point, 
             ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
             ...) + facet_grid(. ~ value)
@@ -438,7 +441,8 @@ interplot.gmlmmi <- function(m, var1, var2, plot = TRUE, steps = NULL, ci = .95,
                 return(coef)
             }
         }
-        coef_df$value <- as.factor(coef_df$value)
+      if (is.null(facet_labs)) facet_labs <- unique(coef_df$value)
+      coef_df$value <- factor(coef_df$value, labels = facet_labs)
         interplot.plot(m = coef_df, steps = steps, hist = hist, var2_dt = var2_dt, point = point, 
             ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
             ...) + facet_grid(. ~ value)
